@@ -1,7 +1,7 @@
 #
 #	Gnu.pm --- The GNU Readline/History Library wrapper module
 #
-#	$Id: Gnu.pm 543 2016-06-07 15:19:45Z hayashi $
+#	$Id: Gnu.pm 548 2016-06-09 17:07:26Z hayashi $
 #
 #	Copyright (c) 1996-2016 Hiroo Hayashi.  All rights reserved.
 #
@@ -69,7 +69,7 @@ use strict;
 use warnings;
 use Carp;
 # use version TRG-1.22 for perl 5.7.x, or TRG-1.09 for older Perl
-use 5.8.1; use 5.008;
+use 5.8.1;
 
 # This module can't be loaded directly.
 BEGIN {
@@ -85,7 +85,7 @@ END
     use Exporter ();
     use DynaLoader;
 
-    our $VERSION = '1.32';		# update Gnu::XS::VERSION also.
+    our $VERSION = '1.33';		# update Gnu::XS::VERSION also.
 
     # Term::ReadLine::Gnu::AU makes a function in
     # `Term::ReadLine::Gnu::XS' as a method.
@@ -773,7 +773,7 @@ sub STORE {
 	# But we must pop the 'stdio' layer only when utf8 layer is
 	# included for remote debugging.
 	#   https://rt.cpan.org/Ticket/Display.html?id=110121
-	if ($] > 5.010) {
+	if ($] >= 5.010) {
 	    my @layers = PerlIO::get_layers($value);
 	    if ((grep /^utf8$/, @layers) > 0 && $layers[$#layers] eq 'stdio') {
 		binmode($value,  ":pop");
